@@ -455,14 +455,20 @@ class TextCog(BaseCog):
         )
 
         local_filename, headers = urllib.request.urlretrieve(drive_link)
+        print("LOCAL FILE:", local_filename)
 
         # check whether or not it's actually been downloaded
         if headers["X-Frame-Options"] == "DENY":
             return ""
 
         text = ""
+
         with open(local_filename, "r", encoding="utf-8-sig") as fp:
             for line in fp:
                 text += line
 
+        # truthfully this shouldn't be necessary but google does something weird
+        remove_double_lines_pattern = re.compile(r"(\n\n)")
+        text = remove_double_lines_pattern.sub("\n", text)
+
         return text
